==> haskell-src-exts-1.18.2-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-src-exts.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-exts
version: 1.18.2
id: haskell-src-exts-1.18.2-7JYrbgADd3D34kjxtkSbG9
key: haskell-src-exts-1.18.2-7JYrbgADd3D34kjxtkSbG9
license: BSD3
maintainer: Niklas Broberg <niklas.broberg@chalmers.se>, Roman Cheplyaka <roma@ro-che.info>
stability: Stable
homepage: https://github.com/haskell-suite/haskell-src-exts
synopsis: Manipulating Haskell source: abstract syntax, lexer, parser, and pretty-printer
description:
    Haskell-Source with Extensions (HSE, haskell-src-exts)
    is a standalone parser for Haskell. In addition to
    standard Haskell, all extensions implemented in GHC are supported.
    .
    Apart from these standard extensions,
    it also handles regular patterns as per the HaRP extension
    as well as HSX-style embedded XML syntax.
category: Language
author: Niklas Broberg
exposed: True
exposed-modules:
    Language.Haskell.Exts Language.Haskell.Exts.Lexer
    Language.Haskell.Exts.Pretty Language.Haskell.Exts.Extension
    Language.Haskell.Exts.Build Language.Haskell.Exts.SrcLoc
    Language.Haskell.Exts.Syntax Language.Haskell.Exts.Fixity
    Language.Haskell.Exts.ExactPrint Language.Haskell.Exts.Parser
    Language.Haskell.Exts.Comments
hidden-modules: Language.Haskell.Exts.ExtScheme
                Language.Haskell.Exts.ParseMonad Language.Haskell.Exts.ParseSyntax
                Language.Haskell.Exts.InternalLexer
                Language.Haskell.Exts.ParseUtils
                Language.Haskell.Exts.InternalParser
abi: 153ea412792db27c7b582cfcce88a43e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/haskell-src-exts-1.18.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/haskell-src-exts-1.18.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/haskell-src-exts-1.18.2
hs-libraries: HShaskell-src-exts-1.18.2-7JYrbgADd3D34kjxtkSbG9
depends:
    array-0.5.1.1 base-4.9.0.0 cpphs-1.20.4-LO4krdoPFZv9dMR7FlkcwT
    ghc-prim-0.5.0.0 pretty-1.1.3.3
haddock-interfaces: /usr/share/doc/haskell-src-exts/html/haskell-src-exts.haddock
haddock-html: /usr/share/doc/haskell-src-exts/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-exts-1.18.2-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-src-exts.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-exts
version: 1.18.2
id: haskell-src-exts-1.18.2-HHC3x3A3NPPIRZVmSBLAjX
key: haskell-src-exts-1.18.2-HHC3x3A3NPPIRZVmSBLAjX
license: BSD3
maintainer: Niklas Broberg <niklas.broberg@chalmers.se>, Roman Cheplyaka <roma@ro-che.info>
stability: Stable
homepage: https://github.com/haskell-suite/haskell-src-exts
synopsis: Manipulating Haskell source: abstract syntax, lexer, parser, and pretty-printer
description:
    Haskell-Source with Extensions (HSE, haskell-src-exts)
    is a standalone parser for Haskell. In addition to
    standard Haskell, all extensions implemented in GHC are supported.
    .
    Apart from these standard extensions,
    it also handles regular patterns as per the HaRP extension
    as well as HSX-style embedded XML syntax.
category: Language
author: Niklas Broberg
exposed: True
exposed-modules:
    Language.Haskell.Exts Language.Haskell.Exts.Lexer
    Language.Haskell.Exts.Pretty Language.Haskell.Exts.Extension
    Language.Haskell.Exts.Build Language.Haskell.Exts.SrcLoc
    Language.Haskell.Exts.Syntax Language.Haskell.Exts.Fixity
    Language.Haskell.Exts.ExactPrint Language.Haskell.Exts.Parser
    Language.Haskell.Exts.Comments
hidden-modules: Language.Haskell.Exts.ExtScheme
                Language.Haskell.Exts.ParseMonad Language.Haskell.Exts.ParseSyntax
                Language.Haskell.Exts.InternalLexer
                Language.Haskell.Exts.ParseUtils
                Language.Haskell.Exts.InternalParser
abi: 82a26722a11ac01acad1300f268c5f26
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/haskell-src-exts-1.18.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/haskell-src-exts-1.18.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/haskell-src-exts-1.18.2
hs-libraries: HShaskell-src-exts-1.18.2-HHC3x3A3NPPIRZVmSBLAjX
depends:
    array-0.5.1.1 base-4.9.0.0 cpphs-1.20.5-9m6GAL7GOtv4Rbh8XXGVgk
    ghc-prim-0.5.0.0 pretty-1.1.3.3
haddock-interfaces: /usr/share/doc/haskell-src-exts/html/haskell-src-exts.haddock
haddock-html: /usr/share/doc/haskell-src-exts/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
